Module drupal — Inmanta 2017.3dev documentation

# Module drupal

> - License: Apache 2.0
> - Version: 0.6.0
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/drupal.git

## Entities

entity `drupal::Application`

  Parents: `php::Application`

  A single drupal application.

  attribute string `admin_password`
  attribute string `admin_user`
  attribute string `admin_email`
  attribute string `site_name`
  relation mysql::Database `database` [1]

  The following implementations are defined for this entity:

  > - `drupal::drupalSiteRPM`
  > - `drupal::drupalSiteDEB`

  The following implements statements select implementations for this entity:

  > - `drupal::drupalSiteRPM`, `php::phpApacheRPM`, `apache::appImplRPM` constraint `(std::familyof(container.host.os,'rhel') or std::familyof(container.host.os,'fedora'))`
  > - `drupal::drupalSiteDEB`, `php::phpApacheDEB`, `apache::appImplDEB` constraint `std::familyof(container.host.os,'ubuntu')`

## Implementations

implementation `drupal::drupalSiteDEB`

implementation `drupal::drupalSiteRPM`